==> fillets-ng-data_0.9.2.orig.tar.gz: fillets-ng-data-0.9.2/script/linux/dialogs_sv.lua <==
dialogId("m-tatinek", "font_small", "Father was right. The linuxers must be mad.")
dialogStr("Pappa hade rätt. Linuxanvändare måste vara tokiga.")
dialogId("v-kdojiny", "font_big", "Who else would make that quantity of barriers.")
dialogStr("Vem annars skulle skapa så många barriärer?")
dialogId("m-zadarmo", "font_small", "To top it all they did it for free.")
dialogStr("Höjden är att de gjorde allt gratis.")

dialogId("m-zamykali", "font_small", "It is clear now, they were locking to protect from us.")
dialogStr("Det är tydligt nu, de låste för att skydda oss.")
dialogId("v-horydoly", "font_big", "They were building mountains, valleys, ...")
dialogStr("De byggde berg, dalar, ...")
dialogId("m-linuxaci", "font_small", "The linuxers!")
dialogStr("Linuxanvändarna!")
dialogId("v-ven", "font_big", "There is only the last task: to put them away.")
dialogStr("Det finns bara den slutgiltiga uppgiften: att ta bort dem.")


dialogId("v-musime", "font_big", "We must put them away.")
dialogStr("Vi måste ta bort dem.")
dialogId("m-radi", "font_small", "I think we should be happy if we manage to get one.")
dialogStr("Jag tror att vi borde vara nöjda om vi fick bort en av dem.")
dialogId("v-radeji", "font_big", "But if we manage both we should be more happy.")
dialogStr("Men om vi får bort båda kommer vi bli lyckligare.")

dialogId("m-nemyslis", "font_small", "Do you think that one linuxer out is enough?")
dialogStr("Tror du att en linuxanvändare är tillräckligt?")
dialogId("v-forkovat", "font_big", "No I don’t. The remaining could fork himself.")
dialogStr("Nej det tror jag inte. Den sista skulle bara gaffla av sig.")


dialogId("m-ukolem", "font_small", "Our goal is to reconcile the linuxers.")
dialogStr("Vår mål är att återställa linuxanvändarna.")
dialogId("v-alespon", "font_big", "or at least to put them away.")
dialogStr("eller åtminstone att ta bort dem.")


dialogId("m-vykaslat", "font_small", "In my opinion it would be better to give up on the linuxers. Anyway they weren’t in the work description.")
dialogStr("Jag tycker att det skulle vara bättre om vi gav upp om linuxanvändarna. Hur som helst fanns de inte i jobbeskrivningen")
dialogId("v-nabourali", "font_big", "But they hacked this game and we can’t win while they will be there.")
dialogStr("Men de hackade det här spelet och vi kan inte vinna så länge de är här.")


dialogId("v-snazit", "font_big", "Wow, you had to try hard to put only one linuxer away. You got over the steel construction.")
dialogStr("Hurra, du fick kämpa rejält för att få bort den ena linuxanvändaren. Du kom över stålkonstruktionen.")
dialogId("m-nestaci", "font_small", "But it isn’t enough to win.")
dialogStr("Men det räcker inte för att vinna.")


dialogId("v-vyrobil", "font_big", "I would like to tell the player to not take this room seriously. After all a linuxer made it.")
dialogStr("Jag skulle vilja säga till spelaren att inte ta den här nivån på allvar. Det var trotts allt en linuxanvändare som gjorde den")
dialogId("m-sileny", "font_small", "He was probably mad.")
dialogStr("Han var antagligen tokig.")

dialogId("v-osobne", "font_big", "Player, if you are a linuxer don’t take the madness personally.")
dialogStr("Spelare, om du är en linuxanvändare så ta inte galenskapen personligen.")
dialogId("m-ostatni", "font_small", "We aren’t talking about you, we are talking about the others.")
dialogStr("Vi pratade inte om dig, vi pratade om andra.")



dialogId("m-samem", "font_small", "It is interesting they are quarreling about the same problems.")
dialogStr("Det är intressant att de bråkar om samma problem.")
dialogId("v-argumenty", "font_big", "And they are using the same arguments.")
dialogStr("Och de använder samma argument.")

dialogId("v-dole", "font_big", "What do you have on the bottom?")
dialogStr("Vad har du på botten?")
dialogId("2-bubliny", "font_linuxer2", "It is frozen bubbles.")
dialogStr("Det är frusna bubblor.")
dialogId("1-odpadnou", "font_linuxer1", "If you join three bubbles of the same color they will fall away.")
dialogStr("Om du länkar samman tre bubblor av samma färg kommer de att falla bort.")

dialogId("m-vtipni", "font_small", "If only the linuxers would be funny.")
dialogStr("Om bara linuxanvändare vore roliga.")
dialogId("1-rozdil", "font_linuxer1", "I know one super joke, do you know the difference between chattr and chmod?")
dialogStr("Jag kan ett super skämt, vet du skillnaden mellan chattr och chmod?")
dialogId("text14", "font_white", "man chattr > 1; man chmod > 2; diff 1 2")
dialogStr("man chattr > 1; man chmod > 2; diff 1 2")
dialogId("2-trapnejsi", "font_linuxer2", "It is more embarrassing than the last comic strip on userfriendly.org.")
dialogStr("Den är ju ännu genantare än den senaste serien på userfriendly.org.")
dialogId("1-trilobyte", "font_linuxer1", "And do you know what is eight trilobites? It is one trilobyte.")
dialogStr("Och vet du vad åtta trilobiter är? Det är en trilobyte")
dialogId("text15", "font_white", "Ha ha ha")
dialogStr("Ha ha ha")



dialogId("2-nezaujata", "font_linuxer2", "Look, this room is trying not be opinionated. There is a penguin at the background. But if there would be logo of Debian, Fedora, ...")
dialogStr("Titta, nivån försöker att inte ta ställning. Det finns en pingvin i bakgrunden. Men om det hade varit logotypen till Debian, Fedora, ...")
dialogId("1-prvni", "font_linuxer1", "Why did you say Debian first?")
dialogStr("Sa du Debian först?")
dialogId("2-abecedy", "font_linuxer2", "I am reciting by the alphabet.")
dialogStr("Jag räknar upp dem i bokstavsordning.")

dialogId("1-archlinux", "font_linuxer1", "So you should start with Arch Linux.")
dialogStr("Borde du inte ha börjat med Arch Linux?")
dialogId("2-zapomel", "font_linuxer2", "Sorry, I forgot it. So Arch Linux, Debian, ...")
dialogStr("Förlåt, jag glömde bort den. Alltså Arch Linux, Debian, ...")
dialogId("1-podruhe", "font_linuxer1", "Why did you say Debian twice?")
dialogStr("Varför sa du Debian två gånger?")

dialogId("2-naprogramovana", "font_linuxer2", "This game was programmed on Debian.")
dialogStr("Det här programmet utvecklades på Debian.")
dialogId("1-ubuntu", "font_linuxer1", "Why wasn’t it done on Ubuntu?")
dialogStr("Varför gjordes det inte på Ubuntu?")
dialogId("2-vykradacka", "font_linuxer2", "Ubuntu is only a bad copy of Debian.")
dialogStr("Ubuntu är bara en dålig kopia av Debian.")

dialogId("1-zkousel", "font_linuxer1", "Did you try Ubuntu?")
dialogStr("Har du testat Ubuntu?")
dialogId("2-root", "font_linuxer2", "No, but it sufficient for me what I heard. Can you log in there as the root?")
dialogStr("Nej, men det borde vara tillräckligt för mig, har jag hört. Kan man logga in som root?")
dialogId("1-nepotrebuje", "font_linuxer1", "Ubuntu doesn’t need antiquities as the root user is.")
dialogStr("Ubuntu behöver inte antikviteter som root användare.")
dialogId("2-postavene", "font_linuxer2", "But it is based on them.")
dialogStr("Men det bygger på dem.")
dialogId("1-rozhrani", "font_linuxer1", "An interface between user and Unix exists in every distribution.")
dialogStr("Ett gränssnitt mellan användare och Unix finns i alla distributioner.")

dialogId("2-slackware", "font_linuxer2", "What about Slackware?")
dialogStr("Hur är det med Slackware?")
dialogId("1-balickovaci", "font_linuxer1", "Oh yes, but its packaging system is lousy.")
dialogStr("Oh ja, men paketsystemet är uselt.")
dialogId("2-svuj", "font_linuxer2", "At least it is owned by Slackware.")
dialogStr("Det ägs åt minstone av Slackware.")


dialogId("2-hadi", "font_linuxer2", "Do you know why are there the snakes?")
dialogStr("Vet du varför ormarna är där?")
dialogId("1-jazyka", "font_linuxer1", "Of course, it is the logo of the best programming language.")
dialogStr("Javisst, det är logotypen till det bästa programmeringsspråket.")
dialogId("2-C", "font_linuxer2", "When did C get logo with snakes?")
dialogStr("När fick C en logga med ormar?")
dialogId("1-prekonane", "font_linuxer1", "The C is outdated a long time ago. Now there is C++ and Java.")
dialogStr("C blev föråldrat för länge sedan. Nu finns C++ och Java.")
dialogId("2-pomala", "font_linuxer2", "Java is interpreted programming language so it is very slow. Your Python is the same case.")
dialogStr("Java är ett interpreterande programmspråk så det är mycket långsamt. Samma sak med ditt Python.")
dialogId("1-pohodli", "font_linuxer1", "I am not interested about speed but the programming comfort.")
dialogStr("Jag är inte intresserad av snabbhet utan av programmeringskomforten.")
dialogId("2-prave", "font_linuxer2", "Yes, you aren’t.")
dialogStr("Ja, det är du.")


dialogId("1-wilber", "font_linuxer1", "Look, Wilber!")
dialogStr("Titta, Wilber!")
dialogId("2-maskot", "font_linuxer2", "It is the mascot of a great graphic application.")
dialogStr("Det är maskoten till det utmärkta grafikprogrammet.")
dialogId("1-dohnat", "font_linuxer1", "Which is trying to catch up Photoshop.")
dialogStr("Som försöker att komma ikapp Photoshop.")
dialogId("2-neni", "font_linuxer2", "The GIMP is not Photoshop. It works on a different basis.")
dialogStr("GIMP är inte Photoshop. Det fungerar på ett annat sätt.")
dialogId("1-zamaskovali", "font_linuxer1", "The GIMP developers assert it to conceal their inability.")
dialogStr("GIMP utvecklarna försäkrar det för att dölja sina svagheter.")


dialogId("1-nebavi", "font_linuxer1", "I am bored by this music.")
dialogStr("Jag har tröttnat på den här musiken.")
dialogId("2-skriptik", "font_linuxer2", "Are you unable to write a script for this?")
dialogStr("Klarar du inte av att skriva ett skript för det där?")
dialogId("v-prepinani", "font_big", "And I am bored by the music switching.")
dialogStr("Och jag har tröttnat på alla musikbyten.")

dialogId("text0", "font_white",  "mplayer kufrik.ogg")
dialogStr("mplayer kufrik.ogg")
dialogId("text1", "font_white",  "mplayer menu.ogg")
dialogStr("mplayer menu.ogg")
dialogId("text2", "font_white",  "mplayer rybky01.ogg")
dialogStr("mplayer rybky01.ogg")
dialogId("text3", "font_white",  "mplayer rybky02.ogg")
dialogStr("mplayer rybky02.ogg")
dialogId("text4", "font_white",  "mplayer rybky03.ogg")
dialogStr("mplayer rybky03.ogg")
dialogId("text5", "font_white",  "mplayer rybky04.ogg")
dialogStr("mplayer rybky04.ogg")
dialogId("text6", "font_white",  "mplayer rybky05.ogg")
dialogStr("mplayer rybky05.ogg")
dialogId("text7", "font_white",  "mplayer rybky06.ogg")
dialogStr("mplayer rybky06.ogg")
dialogId("text8", "font_white",  "mplayer rybky07.ogg")
dialogStr("mplayer rybky07.ogg")
dialogId("text9", "font_white",  "mplayer rybky09.ogg")
dialogStr("mplayer rybky09.ogg")
dialogId("text10", "font_white", "mplayer rybky10.ogg")
dialogStr("mplayer rybky10.ogg")
dialogId("text11", "font_white", "mplayer rybky13.ogg")
dialogStr("mplayer rybky13.ogg")
dialogId("text12", "font_white", "mplayer rybky14.ogg")
dialogStr("mplayer rybky14.ogg")
dialogId("text13", "font_white", "mplayer rybky15.ogg")
dialogStr("mplayer rybky15.ogg")

==> fillets-ng-data_1.0.0.orig.tar.gz: fillets-ng-data-1.0.0/script/linux/dialogs_sv.lua <==
dialogId("m-tatinek", "font_small", "Father was right. The linux users must be mad.")
dialogStr("Pappa hade rätt. Linuxanvändare måste vara tokiga.")
dialogId("v-kdojiny", "font_big", "Who else would make so many barriers.")
dialogStr("Vem annars skulle skapa så många barriärer?")
dialogId("m-zadarmo", "font_small", "To top it all off they did it for free.")
dialogStr("Höjden är att de gjorde allt gratis.")

dialogId("m-zamykali", "font_small", "It is clear now, they were trying to protect themselves from us.")
dialogStr("Det är tydligt nu, de låste för att skydda oss.")
dialogId("v-horydoly", "font_big", "They were building mountains, valleys, ...")
dialogStr("De byggde berg, dalar, ...")
dialogId("m-linuxaci", "font_small", "The linux users!")
dialogStr("Linuxanvändarna!")
dialogId("v-ven", "font_big", "There is one last task: to put them away.")
dialogStr("Det finns bara den slutgiltiga uppgiften: att ta bort dem.")


dialogId("v-musime", "font_big", "We must put them away.")
dialogStr("Vi måste ta bort dem.")
dialogId("m-radi", "font_small", "I think we should be happy if we manage to get one.")
dialogStr("Jag tror att vi borde vara nöjda om vi fick bort en av dem.")
dialogId("v-radeji", "font_big", "But if we manage both we would be happier.")
dialogStr("Men om vi får bort båda kommer vi bli lyckligare.")

dialogId("m-nemyslis", "font_small", "Do you think that gettin one linux user out is enough?")
dialogStr("Tror du att en linuxanvändare är tillräckligt?")
dialogId("v-forkovat", "font_big", "No I don’t. The remaining one could fork himself.")
dialogStr("Nej det tror jag inte. Den sista skulle bara gaffla av sig.")


dialogId("m-ukolem", "font_small", "Our goal is to reconcile the linux users.")
dialogStr("Vår mål är att återställa linuxanvändarna.")
dialogId("v-alespon", "font_big", "Or at least to get them out.")
dialogStr("eller åtminstone att ta bort dem.")


dialogId("m-vykaslat", "font_small", "In my opinion it would be better to give up on the linux users. Anyway, they weren’t in the assignment.")
dialogStr("Jag tycker att det skulle vara bättre om vi gav upp om linuxanvändarna. Hur som helst fanns de inte i jobbeskrivningen")
dialogId("v-nabourali", "font_big", "But they hacked this game and we can’t win while they’re here.")
dialogStr("Men de hackade det här spelet och vi kan inte vinna så länge de är här.")


dialogId("v-snazit", "font_big", "Wow, you had to try pretty hard to put only one linux user away. You got over the steel construction.")
dialogStr("Hurra, du fick kämpa rejält för att få bort den ena linuxanvändaren. Du kom över stålkonstruktionen.")
dialogId("m-nestaci", "font_small", "But it isn’t enough to win.")
dialogStr("Men det räcker inte för att vinna.")


dialogId("v-vyrobil", "font_big", "I would like to tell the player to not take this room too seriously. After all a linux user made it.")
dialogStr("Jag skulle vilja säga till spelaren att inte ta den här nivån på allvar. Det var trotts allt en linuxanvändare som gjorde den")
dialogId("m-sileny", "font_small", "He was probably mad.")
dialogStr("Han var antagligen tokig.")

dialogId("v-osobne", "font_big", "Player, if you are a linux user, don’t take this madness personally.")
dialogStr("Spelare, om du är en linuxanvändare så ta inte galenskapen personligen.")
dialogId("m-ostatni", "font_small", "We aren’t talking about you, we are talking about the others.")
dialogStr("Vi pratade inte om dig, vi pratade om andra.")



dialogId("m-samem", "font_small", "It’s interesting, they are quarreling about the same problems.")
dialogStr("Det är intressant att de bråkar om samma problem.")
dialogId("v-argumenty", "font_big", "And they are using the same arguments.")
dialogStr("Och de använder samma argument.")

dialogId("v-dole", "font_big", "What have you got over there on the bottom?")
dialogStr("Vad har du på botten?")
dialogId("2-bubliny", "font_linuxer2", "Frozen bubbles.")
dialogStr("Det är frusna bubblor.")
dialogId("1-odpadnou", "font_linuxer1", "If you join three bubbles of the same color they will drop away.")
dialogStr("Om du länkar samman tre bubblor av samma färg kommer de att falla bort.")

dialogId("m-vtipni", "font_small", "If only the linux users would be funny.")
dialogStr("Om bara linuxanvändare vore roliga.")
dialogId("1-rozdil", "font_linuxer1", "I know one super joke, do you know the difference between chattr and chmod?")
dialogStr("Jag kan ett super skämt, vet du skillnaden mellan chattr och chmod?")
dialogId("text14", "font_white", "man chattr > 1; man chmod > 2; diff 1 2")
dialogStr("man chattr > 1; man chmod > 2; diff 1 2")
dialogId("2-trapnejsi", "font_linuxer2", "It’s more embarrassing than the last comic strip on userfriendly.org.")
dialogStr("Den är ju ännu genantare än den senaste serien på userfriendly.org.")
dialogId("1-trilobyte", "font_linuxer1", "And do you know what eight trilobites is? It’s one trilobyte.")
dialogStr("Och vet du vad åtta trilobiter är? Det är en trilobyte")
dialogId("text15", "font_white", "Ha ha ha")
dialogStr("Ha ha ha")



dialogId("2-nezaujata", "font_linuxer2", "Look, this room is trying not to be opinionated. There is a penguin in the background, but if there would be logo of Debian, Fedora, ...")
dialogStr("Titta, nivån försöker att inte ta ställning. Det finns en pingvin i bakgrunden. Men om det hade varit logotypen till Debian, Fedora, ...")
dialogId("1-prvni", "font_linuxer1", "Why did you say Debian first?")
dialogStr("Sa du Debian först?")
dialogId("2-abecedy", "font_linuxer2", "I am reciting in alphabetical order.")
dialogStr("Jag räknar upp dem i bokstavsordning.")

dialogId("1-archlinux", "font_linuxer1", "So you should start with Arch Linux.")
dialogStr("Borde du inte ha börjat med Arch Linux?")
dialogId("2-zapomel", "font_linuxer2", "Sorry, I forgot about it. So Arch Linux, Debian, ...")
dialogStr("Förlåt, jag glömde bort den. Alltså Arch Linux, Debian, ...")
dialogId("1-podruhe", "font_linuxer1", "Why did you say Debian twice?")
dialogStr("Varför sa du Debian två gånger?")

dialogId("2-naprogramovana", "font_linuxer2", "This game was programmed on Debian.")
dialogStr("Det här programmet utvecklades på Debian.")
dialogId("1-ubuntu", "font_linuxer1", "Why wasn’t it done on Ubuntu?")
dialogStr("Varför gjordes det inte på Ubuntu?")
dialogId("2-vykradacka", "font_linuxer2", "Ubuntu is just a bad copy of Debian.")
dialogStr("Ubuntu är bara en dålig kopia av Debian.")

dialogId("1-zkousel", "font_linuxer1", "Have you tried Ubuntu?")
dialogStr("Har du testat Ubuntu?")
dialogId("2-root", "font_linuxer2", "No, but I’ve heard plenty. Can you log in as the root on it?")
dialogStr("Nej, men det borde vara tillräckligt för mig, har jag hört. Kan man logga in som root?")
dialogId("1-nepotrebuje", "font_linuxer1", "Ubuntu doesn’t need antiquities like a root user.")
dialogStr("Ubuntu behöver inte antikviteter som root användare.")
dialogId("2-postavene", "font_linuxer2", "But it is based on them.")
dialogStr("Men det bygger på dem.")
dialogId("1-rozhrani", "font_linuxer1", "An interface between the user and Unix exists in every distribution.")
dialogStr("Ett gränssnitt mellan användare och Unix finns i alla distributioner.")

dialogId("2-slackware", "font_linuxer2", "What about Slackware?")
dialogStr("Hur är det med Slackware?")
dialogId("1-balickovaci", "font_linuxer1", "Oh yes, but its packaging system is lousy.")
dialogStr("Oh ja, men paketsystemet är uselt.")
dialogId("2-svuj", "font_linuxer2", "At least it’s owned by Slackware.")
dialogStr("Det ägs åt minstone av Slackware.")


dialogId("2-hadi", "font_linuxer2", "Do you know why there are snakes?")
dialogStr("Vet du varför ormarna är där?")
dialogId("1-jazyka", "font_linuxer1", "Of course, it’s the logo of the best programming language.")
dialogStr("Javisst, det är logotypen till det bästa programmeringsspråket.")
dialogId("2-C", "font_linuxer2", "When did C get a logo with snakes?")
dialogStr("När fick C en logga med ormar?")
dialogId("1-prekonane", "font_linuxer1", "C is ancient and outdated. Now there are C++ and Java.")
dialogStr("C blev föråldrat för länge sedan. Nu finns C++ och Java.")
dialogId("2-pomala", "font_linuxer2", "Java is an interpreted programming language so it’s very slow. Your Python has the same problem.")
dialogStr("Java är ett interpreterande programmspråk så det är mycket långsamt. Samma sak med ditt Python.")
dialogId("1-pohodli", "font_linuxer1", "I am not interested in speed but in programming comfort.")
dialogStr("Jag är inte intresserad av snabbhet utan av programmeringskomforten.")
dialogId("2-prave", "font_linuxer2", "Yes, you are.")
dialogStr("Ja, det är du.")


dialogId("1-wilber", "font_linuxer1", "Look, Wilber!")
dialogStr("Titta, Wilber!")
dialogId("2-maskot", "font_linuxer2", "It is the mascot of a great graphics application.")
dialogStr("Det är maskoten till det utmärkta grafikprogrammet.")
dialogId("1-dohnat", "font_linuxer1", "Which is trying to catch up to Photoshop.")
dialogStr("Som försöker att komma ikapp Photoshop.")
dialogId("2-neni", "font_linuxer2", "The GIMP is not Photoshop. It works completely differently.")
dialogStr("GIMP är inte Photoshop. Det fungerar på ett annat sätt.")
dialogId("1-zamaskovali", "font_linuxer1", "The GIMP developers say that to conceal their inability.")
dialogStr("GIMP utvecklarna försäkrar det för att dölja sina svagheter.")


dialogId("1-nebavi", "font_linuxer1", "I am bored with this music.")
dialogStr("Jag har tröttnat på den här musiken.")
dialogId("2-skriptik", "font_linuxer2", "Couldn’t you write a script for this?")
dialogStr("Klarar du inte av att skriva ett skript för det där?")
dialogId("v-prepinani", "font_big", "And I am bored with the music switching.")
dialogStr("Och jag har tröttnat på alla musikbyten.")

dialogId("text0", "font_white",  "mplayer kufrik.ogg")
dialogStr("mplayer kufrik.ogg")
dialogId("text1", "font_white",  "mplayer menu.ogg")
dialogStr("mplayer menu.ogg")
dialogId("text2", "font_white",  "mplayer rybky01.ogg")
dialogStr("mplayer rybky01.ogg")
dialogId("text3", "font_white",  "mplayer rybky02.ogg")
dialogStr("mplayer rybky02.ogg")
dialogId("text4", "font_white",  "mplayer rybky03.ogg")
dialogStr("mplayer rybky03.ogg")
dialogId("text5", "font_white",  "mplayer rybky04.ogg")
dialogStr("mplayer rybky04.ogg")
dialogId("text6", "font_white",  "mplayer rybky05.ogg")
dialogStr("mplayer rybky05.ogg")
dialogId("text7", "font_white",  "mplayer rybky06.ogg")
dialogStr("mplayer rybky06.ogg")
dialogId("text8", "font_white",  "mplayer rybky07.ogg")
dialogStr("mplayer rybky07.ogg")
dialogId("text9", "font_white",  "mplayer rybky09.ogg")
dialogStr("mplayer rybky09.ogg")
dialogId("text10", "font_white", "mplayer rybky10.ogg")
dialogStr("mplayer rybky10.ogg")
dialogId("text11", "font_white", "mplayer rybky13.ogg")
dialogStr("mplayer rybky13.ogg")
dialogId("text12", "font_white", "mplayer rybky14.ogg")
dialogStr("mplayer rybky14.ogg")
dialogId("text13", "font_white", "mplayer rybky15.ogg")
dialogStr("mplayer rybky15.ogg")
